<?php

/**
 * @file
 * Drush commands for UCB Events.
 */

/**
 * Implements hook_drush_command().
 */
function ucbevents_drush_command() {
  $items = array();

  $items['ucbevents-list'] = array(
    'description' => 'Describe some or all event feeds.',
    'arguments' => array(
      'fids' => 'Optional. A space delimited list of feed ids. If omitted, a summary is shown.',
    ),
    'aliases' => array('ucbevents'),
  );
  $items['ucbevents-add'] = array(
    'description' => 'Add an event feed.',
    'arguments' => array(
      'title' => 'Feed title',
      'url' => 'URL',
    ),
    'options' => array(
      'refresh' => 'Refresh time, in seconds.  Defaults to 6 hours.',
      'link' => 'Link to a human-readable version of the feed',
    ),
  );
  $items['ucbevents-refresh'] = array(
    'description' => 'Refresh event feeds.',
    'arguments' => array(
      'fids' => 'A space delimited list of feed ids.',
    ),
    'options' => array(
      'all' => 'Refresh all feeds.',
    )
  );
  $items['ucbevents-remove'] = array(
    'description' => 'Refresh event feeds.',
    'arguments' => array(
      'fid' => 'A feed id.',
    ),
    'aliases' => array('ucbevents-rm'),
  );

  return $items;
}

/**
 * Implements hook_drush_help().
 */
function ucbevents_drush_help($section) {
  switch ($section) {
    case 'meta:ucbevents:title':
      return dt('UCB Events commands');
    case 'meta:ucbevents:title':
      return dt('Add, remove, and refresh event feeds');
    case 'drush:ucbevents-add':
      return dt('Add an event feed.');
    case 'drush:ucbevents-list':
      return dt('List event feeds.');
    case 'drush:ucbevents-refresh':
      return dt('Refresh event feeds.');
    case 'drush:ucbevents-remove':
      return dt('Remove an event feed.');
  }
}

/**
 * Refresh event feeds.
 */
function drush_ucbevents_refresh() {
  if (drush_get_option('all')) {
    ucbevents_refresh_all();
  }
  elseif ($fids = func_get_args()) {
    ucbevents_refresh_multiple($fids);
  }
  else {
    drush_print('No feeds specified.  Did you mean \'--all\'?');
  }
}

/**
 * List event feeds.
 */
function drush_ucbevents_list() {
  $fids = func_get_args();
  if (empty($fids)) {
    $header = array(dt('Id'), dt('Title'), dt('Last Refreshed'));
    $rows = array();
    $result = db_query('SELECT * FROM {ucbevents_feed}');
    while ($feed = db_fetch_object($result)) {
      $rows[] = array(
        $feed->fid,
        check_plain($feed->title),
        dt('@ago ago', array('@ago' => format_interval($_SERVER['REQUEST_TIME']-$feed->checked))),
      );
    }
    $table = new Console_Table();
    drush_print($table->fromArray($header, $rows));
  }
  else {
    $result = db_query('SELECT * FROM {ucbevents_feed} WHERE fid IN (' . db_placeholders($fids) . ')', $fids);
    while ($feed = db_fetch_array($result)) {
      $header = array(dt('Key'), dt('Value'));
      $rows = array();
      foreach ($feed as $key => $value) {
        $rows[] = array($key, $value);
      }
      $table = new Console_Table();
      drush_print($table->fromArray($header, $rows));
    }
  }
}

/**
 * Add an event feed.
 */
function drush_ucbevents_add($title = NULL, $url = NULL) {
  if (!$refresh = drush_get_option('refresh')) {
    $refresh = 6*60*60;
  }
  if (!$link = drush_get_option('link')) {
    $link = '';
  }

  // Build feed and insert it.
  $feed = array(
    'title' => $title,
    'url' => $url,
    'refresh' => $refresh,
    'link' => $link,
  );
  drupal_write_record('ucbevents_feed', $feed);
}

/**
 * Add an event feed; function validator.
 */
function drush_ucbevents_add_validate($title = NULL, $url = NULL) {
  if (empty($title)) {
    return drush_set_error(dt('Missing argument: title'));
  }
  if (empty($url)) {
    return drush_set_error(dt('Missing argument: url'));
  }
}

/**
 * Remove an event feed.
 */
function drush_ucbevents_remove($fid = NULL) {
  $title = db_result(db_query('SELECT title FROM {ucbevents_feed} WHERE fid = %d', $fid));

  if (drush_confirm(dt('Are you sure you want to delete feed @title?', array('@title' => $title)))) {
    db_query('DELETE FROM {ucbevents_feed} WHERE fid = %d', $fid);
    ucbevents_garbage_collect();
    drush_print(dt('Successfully removed feed @title', array('@title' => $title)));
  }
}

/**
 * Remove an event feed; function validator.
 */
function drush_ucbevents_remove_validate($fid = NULL) {
  if (!isset($fid)) {
    return drush_set_error(dt('Missing argument: fid'));
  }
  $count = db_result(db_query('SELECT COUNT(*) FROM {ucbevents_feed} WHERE fid = %d', $fid));
  if (!$count) {
    return drush_set_error(dt('Specified feed does not exist.'));
  }
}
